@@ -55,12 +55,12 @@ class MyBarLogger(ProgressBarLogger):
             self.start_count_time_30= time.time()
 
 
-def create_lyric_outro(deezer_artist_id, lyric_outro_repeat,  arr_comp, time_o=5):
+def create_lyric_outro(deezer_artist_id, lyric_outro_repeat,  arr_comp, outro_claim_topic = None, time_o=5):
     if deezer_artist_id == 977996688 or deezer_artist_id == 96969996688:
         return None
     path_video = None
     try:
-        outro_sound = MusicHelper.create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat)
+        outro_sound = MusicHelper.create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat, outro_claim_topic)
         path_video = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid-audio.mp4")
         tmp_path_composite_outro = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid.mp4")
         tmp_clip = CompositeVideoClip(arr_comp).subclip(0, time_o)
@@ -108,6 +108,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     is_lyric_outro = False
     deezer_artist_id = None
     audio_compilation_path=None
+    outro_claim_topic=None
     cnt_effect_vid=0
     introPath = None
     outroPath = None
@@ -125,6 +126,10 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
             if is_lyric_outro:
                 deezer_artist_id = comp.deezer_artist_id
                 lyric_outro_repeat = comp.lyric_outro_repeat
+                is_outro_claim=comp.is_outro_claim
+                if is_outro_claim:
+                    outro_claim_topic =  comp.outro_claim_topic
+
         if comp.type == "compilation":
             is_compilation = True
             #test
@@ -241,7 +246,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     duration_f = final_vid.duration
     final_vid.close()
     if is_lyric_outro:
-        lyricOutroPath = create_lyric_outro(deezer_artist_id, lyric_outro_repeat, firstImageOrVideoBG)
+        lyricOutroPath = create_lyric_outro(deezer_artist_id, lyric_outro_repeat, firstImageOrVideoBG, outro_claim_topic)
         path_video = merge_intro_outro(path_video, None, lyricOutroPath)
     path_video = merge_intro_outro(path_video, introPath, outroPath)
     for comp in arr_comps:
@@ -440,12 +445,16 @@ class TextComp(Component):
             # self.calcWidthHigh()
             font_size, h_text = self.get_max_font_size(self.font_url, self.text,
                                                        int(self.position['width']), self.font_size)
+            h_text = int(h_text + math.ceil(h_text / 3))
             if font_size:
                 self.font_size = font_size
-                self.position['y'] = self.position['y'] - (h_text - self.position['height'])
-                self.position['height'] = h_text
-                if self.position['y'] < 50:
-                    self.position['y']=50
+                if h_text > self.position['height']:
+                    h_text = int(h_text + math.ceil(h_text / 3))
+                    self.position['y'] = self.position['y'] - (h_text - self.position['height'])
+                    self.position['height'] = h_text
+                    if self.position['y'] < 50:
+                        self.position['y']=50
+
         rs = TextClip(txt = self.text, font = self.font_path.replace("\\","/"), fontsize=self.font_size, color=self.color,
                         bg_color = self.bg_color, size=(int(self.position['width']), int(self.position['height'])+10),
                         stroke_color = self.stroke_color, stroke_width=self.stroke_width)
@@ -579,12 +588,18 @@ class LyricComp(Component):
         self.fade_in = json_data['fade_in']
         self.fade_out = json_data['fade_out']
         self.is_lyric_outro=False
+        self.is_lyric_outro=False
+        self.outro_claim_topic =None
         if "is_lyric_outro" in json_data:
             self.is_lyric_outro = json_data['is_lyric_outro']
             if "deezer_artist_id" in json_data:
                 self.deezer_artist_id = json_data['deezer_artist_id']
             if "lyric_outro_repeat" in json_data:
                 self.lyric_outro_repeat = json_data['lyric_outro_repeat']
+            if "is_outro_claim" in json_data:
+                self.is_outro_claim = json_data['is_outro_claim']
+            if "outro_claim_topic" in json_data:
+                self.outro_claim_topic = json_data['outro_claim_topic']
 
     def get_clip(self):
         self.lyric = Lyric(self.lyric_sync, self.font_url, self.font_size, self.color,
