@@ -159,6 +159,14 @@ def convert_gif(video_path, is_del=True):
     if is_del:
         os.remove(video_path)
     return tmp_clip_path_z
+def convert_gif_moviepy(video_path, is_del=True):
+    tmp_clip_path_z = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-gif.avi')
+    clip = VideoFileClip(video_path,audio=False, has_mask=True)
+    clip.write_videofile(tmp_clip_path_z, fps=clip.fps, codec='libx264')
+    clip.close()
+    if is_del:
+        os.remove(video_path)
+    return tmp_clip_path_z
 def create_loop(clip_path, loop_duration, can_loopable = True):
     try:
         clip = VideoFileClip(clip_path)
